/* Includes ------------------------------------------------------------------*/
#include "stm32f10x.h"
		  
/* Private define ------------------------------------------------------------*/

/* Private variables ---------------------------------------------------------*/
int a; //zmienna definiujaca aktualna konfiguracje danego trybu
int b; //zmienna definiujaca aktualny tryb dzialania: 0 - brak generowanego sygnalu, 1 - generowany sygnal PWM, 2 - generowany sygnal zegarowy
int c[] = {0,2,4,8,15,30,60,125,175,250,500,1000};	//tablica sterowania wypelnieniem sygnalu PWM

/* Private function prototypes -----------------------------------------------*/
void RCC_Configuration(void);

/* Private functions ---------------------------------------------------------*/

int main(void)
{
	//definiowanie wykorzystywanych struktur
	GPIO_InitTypeDef GPIO_InitStructure;
	EXTI_InitTypeDef EXTI_InitStructure;
	NVIC_InitTypeDef NVIC_InitStructure;
	//konfiguracja RCCmikrokontrolera
	RCC_Configuration();
	//wlaczenie sygnalu zegarowego dla wykorzystywanych elementow: TIM1, GPIOE, AFIO 
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_AFIO | RCC_APB2Periph_GPIOE | RCC_APB2Periph_TIM1, ENABLE);
	//ustawienie portw wyjsc (sterowanie diodami LED), LED1 - sterowany przez timer, LED2 zapalony na stale
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_14;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_OD;
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	GPIO_Init(GPIOE, &GPIO_InitStructure);
	//
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_15;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	GPIO_Init(GPIOE, &GPIO_InitStructure);
	GPIO_ResetBits(GPIOE, GPIO_Pin_15);
	//konfiguracja pinow generujacych przerwanie
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8 | GPIO_Pin_9 | GPIO_Pin_10 | GPIO_Pin_11 | GPIO_Pin_12;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN_FLOATING  ;
	GPIO_Init(GPIOE, &GPIO_InitStructure); 
	//zdefiniowanie polozenia tablicy przerwan 
	NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x0);
	//wybranie grupy priorytetow
	NVIC_PriorityGroupConfig(NVIC_PriorityGroup_1);
	//konfiguracja NVIC dla przerwania EXTI9_5_IRQn
	NVIC_InitStructure.NVIC_IRQChannel = EXTI9_5_IRQn;
	NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
	NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
	NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
	NVIC_Init(&NVIC_InitStructure);
	//konfiguracja NVIC dla przerwania EXTI15_10_IRQn
	NVIC_InitStructure.NVIC_IRQChannel = EXTI15_10_IRQn;
	NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
	NVIC_Init(&NVIC_InitStructure);
	//ustwienie dzialania GPIO jako linii EXTI
	GPIO_EXTILineConfig(GPIO_PortSourceGPIOE, GPIO_PinSource8);
	GPIO_EXTILineConfig(GPIO_PortSourceGPIOE, GPIO_PinSource9);
	GPIO_EXTILineConfig(GPIO_PortSourceGPIOE, GPIO_PinSource10);
	GPIO_EXTILineConfig(GPIO_PortSourceGPIOE, GPIO_PinSource11);
  	GPIO_EXTILineConfig(GPIO_PortSourceGPIOE, GPIO_PinSource12);
	//ustawienie sposobu generowania przerwania
  	EXTI_InitStructure.EXTI_Line = EXTI_Line8 | EXTI_Line9 | EXTI_Line10 | EXTI_Line11 | EXTI_Line12;
  	EXTI_InitStructure.EXTI_Mode = EXTI_Mode_Interrupt;
  	EXTI_InitStructure.EXTI_Trigger = EXTI_Trigger_Falling;
  	EXTI_InitStructure.EXTI_LineCmd = ENABLE;
  	EXTI_Init(&EXTI_InitStructure);
	//wlaczenie reampingu timera1 umozliwiajac w ten sposob sterowanie dioda LED1, poprzez kanal 4
	GPIO_PinRemapConfig(GPIO_FullRemap_TIM1, ENABLE);

	while(1){}
}

void RCC_Configuration(void)
{
	ErrorStatus HSEStartUpStatus;

	//Reset ustawien RCC
	RCC_DeInit();

	//Wlaczaenie HSE
	RCC_HSEConfig(RCC_HSE_ON);

	//Zaczekaj az HSE zostaeni zainicjowany
	HSEStartUpStatus = RCC_WaitForHSEStartUp();

	if(HSEStartUpStatus == SUCCESS)
	{
		//Wlaczenie buffora pamieci flash
		FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);

		//Opoznienie dla pamieci Flash
		FLASH_SetLatency(FLASH_Latency_2);

		//configuration of AHB prescaler
		//HCLK = SYSCLK
		RCC_HCLKConfig(RCC_SYSCLK_Div1);

		//configuration of APB2 prescaler
	    //PCLK2 = HCLK = 72MHz, czestotliwosz 72MHz bedzie uzyskana dopiero po pelnej inicjalizacji RCC 
		RCC_PCLK2Config(RCC_HCLK_Div1); 
    
	    //configuration of APB1 prescaler
		//PCLK1 = HCLK/2 = 36MHz, czestotliwosz 36MHz bedzie uzyskana dopiero po pelnej inicjalizacji RCC
		RCC_PCLK1Config(RCC_HCLK_Div2); 

	 	//configuration of PREDIV2
		//PREDIV2 configuration: PREDIV2CLK = HSE / 2 = 5Hz
	    RCC_PREDIV2Config(RCC_PREDIV2_Div2 ); 

		//configuration of PLL3MUL
		//ustawienia dla szyny MCO do obslugi Ethernetu
	    //PLL3 configuration: PLL3CLK = (HSE / 2) * 10 = 50 MHz
		RCC_PLL3Config(RCC_PLL3Mul_10);
		
		//Enable PLL3
		RCC_PLL3Cmd(ENABLE);

	   	//Wait till PLL3 is ready
	    while(RCC_GetFlagStatus(RCC_FLAG_PLL3RDY) == RESET){}

		//MCO configuration
		//MCO_OUT = PLL3 / 2 = 25MHz for PHY MII
	    RCC_MCOConfig(RCC_MCO_PLL3CLK_Div2);

	    //configuration of PLL2MUL
		//PLL2 configuration: PLL2CLK = (HSE / 2) * 8 = 40 MHz
	  	RCC_PLL2Config(RCC_PLL2Mul_8);
	    
		//Enable PLL2
		RCC_PLL2Cmd(ENABLE); 
	
	    //Wait till PLL2 is ready
	    while(RCC_GetFlagStatus(RCC_FLAG_PLL2RDY) == RESET){}
	    
		//configuration of PREDIV1
		//PREDIV1CLK = PLL2 / 5 = 8 MHz 
	   	RCC_PREDIV1Config(RCC_PREDIV1_Source_PLL2,RCC_PREDIV1_Div5);
	
	    //configuration of PLL
		//PLLCLK = PREDIV1 * 9 = 72 MHz 
		RCC_PLLConfig(RCC_PLLSource_PREDIV1, RCC_PLLMul_9); 
								
		//Enable PLL
	    RCC_PLLCmd (ENABLE);	
	
	    //Wait till PLL is ready
	    while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET){}
	    
	    //configuration of SW
		//Select PLL as system clock source
		RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK); 
	
	    //Wait till PLL is used as system clock source
	    while ((RCC->CFGR & (uint32_t)RCC_CFGR_SWS) != (uint32_t)0x08){}	

	}
}
