/**
  ******************************************************************************
  * @file    Project/Template/stm32f10x_it.c 
  * @author  MCD Application Team
  * @version V3.1.2
  * @date    09/28/2009
  * @brief   Main Interrupt Service Routines.
  *          This file provides template for all exceptions handler and 
  *          peripherals interrupt service routine.
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2009 STMicroelectronics</center></h2>
  */ 

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x_it.h"

/** @addtogroup Template_Project
  * @{
  */

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/******************************************************************************/
/*            Cortex-M3 Processor Exceptions Handlers                         */
/******************************************************************************/

/**
  * @brief   This function handles NMI exception.
  * @param  None
  * @retval None
  */
void NMI_Handler(void)
{
}

/**
  * @brief  This function handles Hard Fault exception.
  * @param  None
  * @retval None
  */
void HardFault_Handler(void)
{
  /* Go to infinite loop when Hard Fault exception occurs */
  while (1)
  {
  }
}

/**
  * @brief  This function handles Memory Manage exception.
  * @param  None
  * @retval None
  */
void MemManage_Handler(void)
{
  /* Go to infinite loop when Memory Manage exception occurs */
  while (1)
  {
  }
}

/**
  * @brief  This function handles Bus Fault exception.
  * @param  None
  * @retval None
  */
void BusFault_Handler(void)
{
  /* Go to infinite loop when Bus Fault exception occurs */
  while (1)
  {
  }
}

/**
  * @brief  This function handles Usage Fault exception.
  * @param  None
  * @retval None
  */
void UsageFault_Handler(void)
{
  /* Go to infinite loop when Usage Fault exception occurs */
  while (1)
  {
  }
}

/**
  * @brief  This function handles SVCall exception.
  * @param  None
  * @retval None
  */
void SVC_Handler(void)
{
}

/**
  * @brief  This function handles Debug Monitor exception.
  * @param  None
  * @retval None
  */
void DebugMon_Handler(void)
{
}

/**
  * @brief  This function handles PendSVC exception.
  * @param  None
  * @retval None
  */
void PendSV_Handler(void)
{
}

/**
  * @brief  This function handles SysTick Handler.
  * @param  None
  * @retval None
  */
void SysTick_Handler(void)
{
}


/**
  * @brief  This function handles External lines 9 to 5 interrupt request.
  * @param  None
  * @retval None
  */
void EXTI9_5_IRQHandler(void)
{
	//zdefiniowanie zmiennej zadeklarowanej w pliku main.c
	extern int a;
	extern int b;
	extern int c[];
	//przerwanie wywolane przez joystick w pozycji - ok
	if(EXTI_GetITStatus(EXTI_Line8) != RESET)
  	{
		//ustawienie trybu dzialania
		b = 0;
		//wylaczenie timera TIM1
		TIM_Cmd(TIM1, DISABLE);
		//wylaczenie pinow wyjsciowych timera
		TIM_CtrlPWMOutputs(TIM1, DISABLE);
    	//wyczyszczenie flagi przerwania
		EXTI_ClearITPendingBit(EXTI_Line8);
  	}
	//przerwanie wywolane przez joystick w pozycji - up
	else if(EXTI_GetITStatus(EXTI_Line9) != RESET)
  	{
		if(b == 1)
		{
			//ustawienie aktualnej konfiguracji
			a += 1; 
			if(a > 11){a = 11;}
			//aktualizacja wartosci rejestru CCR4 licznika TIM1
			TIM1->CCR4 = 1000 - c[a];
		}
		else if(b == 2)
		{
			//ustawienie aktualnej konfiguracji
			a -= 1;
			if(a < 1){a = 1;}
			//aktualizacja wartosci rejestru ARR licznika TIM1
			TIM1->ARR = a * 34;
			//wyzerowanie wartosci rejestru CNT licznika TIM1
			TIM1->CNT = 0;
		}
     	//wyczyszczenie flagi przerwania
		EXTI_ClearITPendingBit(EXTI_Line9);
  	}
}

/**
  * @brief  This function handles External lines 15 to 10 interrupt request.
  * @param  None
  * @retval None
  */
void EXTI15_10_IRQHandler(void)
{
	//definiowanie wykorzystywanych struktur
	TIM_TimeBaseInitTypeDef TIM_TimeBaseStructure;
	TIM_OCInitTypeDef Tim_OCInitStructure;
	//zdefiniowanie zmiennej zadeklarowanej w pliku main.c
	extern int a;
	extern int b;
	extern int c[];
	//przerwanie wywolane przez joystick w pozycji - down
	if(EXTI_GetITStatus(EXTI_Line10) != RESET)
  	{
		if(b == 1)
		{
			//ustawienie aktualnej konfiguracji
			a -= 1;
			if(a < 0){a = 0;}
			//aktualizacja wartosci rejestru CCR4 licznika TIM1
			TIM1->CCR4 = 1000 - c[a];
		}
		else if(b == 2)
		{
			//ustawienie aktualnej konfiguracji
			a += 1;
			if(a > 16){a = 16;}
			//aktualizacja wartosci rejestru ARR licznika TIM1
			TIM1->ARR = a * 34;
			//wyzerowanie wartosci rejestru CNT licznika TIM1
			TIM1->CNT = 0;	 
		}
		//wyczyszczenie flagi przerwania
		EXTI_ClearITPendingBit(EXTI_Line10);
  	}
	//przerwanie wywolane przez joystick w pozycji - right
	else if(EXTI_GetITStatus(EXTI_Line11) != RESET)
  	{
		//ustawienie trybu dzialania oraz aktualnej konfiguracji
		b = 2;
		a = 8;
		//konfiguracja timera TIM1 jako generatora sygnalu wolnozmiennego
		//poprzez zadane wartosci dzielnika zegara i preskalera czestotliwosc wynosi okolo 274 Hz
		TIM_TimeBaseStructure.TIM_Period = a * 34;
		TIM_TimeBaseStructure.TIM_Prescaler = 0xFFFF;
		TIM_TimeBaseStructure.TIM_ClockDivision = TIM_CKD_DIV4;
		TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;
		TIM_TimeBaseInit(TIM1, &TIM_TimeBaseStructure);		
		//konfiguracja kanalu 4 timera TIM1
		Tim_OCInitStructure.TIM_OCMode = TIM_OCMode_Toggle;
		Tim_OCInitStructure.TIM_OutputState = TIM_OutputState_Enable;
		Tim_OCInitStructure.TIM_Pulse = 17;
		Tim_OCInitStructure.TIM_OCPolarity = TIM_OCPolarity_High;
		TIM_OC4Init(TIM1, &Tim_OCInitStructure);
		TIM_OC4PreloadConfig(TIM1, TIM_OCPreload_Enable);
		//zaladowanie konfiguracji
		TIM_ARRPreloadConfig(TIM1, DISABLE);
		//wlaczenie timera TIM1
		TIM_Cmd(TIM1, ENABLE);
		//wlaczenie pinow wyjsciowych timera
		TIM_CtrlPWMOutputs(TIM1, ENABLE);
    	//wyczyszczenie flagi przerwania
		EXTI_ClearITPendingBit(EXTI_Line11);
  	}
	//przerwanie wywolane przez joystick w pozycji - left
	else if(EXTI_GetITStatus(EXTI_Line12) != RESET)
  	{
		//ustawienie trybu dzialania oraz aktualnej konfiguracji
		b = 1;
		a = 6;		
 		// konfiguracja timera TIM1
		TIM_TimeBaseStructure.TIM_Period = 999;
		TIM_TimeBaseStructure.TIM_Prescaler = 0xFF;
		TIM_TimeBaseStructure.TIM_ClockDivision = TIM_CKD_DIV4;
		TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;
		TIM_TimeBaseInit(TIM1, &TIM_TimeBaseStructure);		
		//konfiguracja kanalu 4
		Tim_OCInitStructure.TIM_OCMode = TIM_OCMode_PWM1;
		Tim_OCInitStructure.TIM_OutputState = TIM_OutputState_Enable;
		Tim_OCInitStructure.TIM_Pulse = 1000 - c[a];
		Tim_OCInitStructure.TIM_OCPolarity = TIM_OCPolarity_High;
		TIM_OC4Init(TIM1, &Tim_OCInitStructure);
		TIM_OC4PreloadConfig(TIM1, TIM_OCPreload_Enable);
		//zaladowanie konfiguracji
		TIM_ARRPreloadConfig(TIM1, ENABLE);
		//wlaczenie timera TIM3
		TIM_Cmd(TIM1, ENABLE);
		//wlaczenie pinow wyjsciowych timera
		TIM_CtrlPWMOutputs(TIM1, ENABLE);
		//wyczyszczenie flagi przerwania
		EXTI_ClearITPendingBit(EXTI_Line12);
  	}
}

/******************************************************************************/
/*                 STM32F10x Peripherals Interrupt Handlers                   */
/*  Add here the Interrupt Handler for the used peripheral(s) (PPP), for the  */
/*  available peripheral interrupt handler's name please refer to the startup */
/*  file (startup_stm32f10x_xx.s).                                            */
/******************************************************************************/

/**
  * @brief  This function handles PPP interrupt request.
  * @param  None
  * @retval None
  */
/*void PPP_IRQHandler(void)
{
}*/

/**
  * @}
  */ 


/******************* (C) COPYRIGHT 2009 STMicroelectronics *****END OF FILE****/
